<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>IncDecVolumeCommandLineOption</name>
    <message>
        <location filename="../incdecvolumeoption.cpp" line="44"/>
        <source>Increase volume with step 5</source>
        <translation>Lautstärke erhöhen (in Fünfer-Schritten)</translation>
    </message>
    <message>
        <location filename="../incdecvolumeoption.cpp" line="45"/>
        <source>Decrease volume with step 5</source>
        <translation>Lautstärke verringern (in Fünfer-Schritten)</translation>
    </message>
</context>
</TS>
